@@ -1,11 +1,24 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2013 OpenStack Foundation
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 import json
-import uuid
 
 import sqlalchemy as sql
-from sqlalchemy import orm
 
 from keystone import config
-from keystone import exception
 
 
 CONF = config.CONF
@@ -15,9 +28,9 @@ def upgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
 
-    user_table = sql.Table('user', meta, autoload=True)
-    role_table = sql.Table('role', meta, autoload=True)
-    project_table = sql.Table('project', meta, autoload=True)
+    sql.Table('user', meta, autoload=True)
+    sql.Table('role', meta, autoload=True)
+    sql.Table('project', meta, autoload=True)
     new_metadata_table = sql.Table('user_project_metadata',
                                    meta,
                                    autoload=True)
@@ -26,11 +39,9 @@ def upgrade(migrate_engine):
     session = sql.orm.sessionmaker(bind=migrate_engine)()
 
     for metadata in session.query(old_metadata_table):
-        if not config.CONF.member_role_id in metadata.data:
-            data = json.loads(metadata.data)
+        data = json.loads(metadata.data)
+        if config.CONF.member_role_id not in metadata.data:
             data['roles'].append(config.CONF.member_role_id)
-        else:
-            data = metadata.data
 
         r = session.query(new_metadata_table).filter_by(
             user_id=metadata.user_id,
@@ -61,19 +72,18 @@ def downgrade(migrate_engine):
     meta = sql.MetaData()
     meta.bind = migrate_engine
 
-    user_table = sql.Table('user', meta, autoload=True)
-    project_table = sql.Table('project', meta, autoload=True)
+    sql.Table('user', meta, autoload=True)
+    sql.Table('project', meta, autoload=True)
 
     metadata_table = sql.Table(
         'metadata',
         meta,
         sql.Column(
-            'user_id',
+            u'user_id',
             sql.String(64),
-            sql.ForeignKey('user.id'),
             primary_key=True),
         sql.Column(
-            'tenant_id',
+            u'tenant_id',
             sql.String(64),
             primary_key=True),
         sql.Column('data',
@@ -94,9 +104,8 @@ def downgrade(migrate_engine):
 
     for metadata in session.query(user_project_metadata_table):
         if 'roles' in metadata:
-            roles = json.loads(metadata.data)
-            ins = (metadata_table.insert()
-                   .values(user_id=metadata.user_id,
-                           tenant_id=metadata.project_id))
+            metadata_table.insert().values(
+                user_id=metadata.user_id,
+                tenant_id=metadata.project_id)
 
     session.close()
