@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 OpenStack LLC
+# Copyright 2012 OpenStack Foundation
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,11 +17,10 @@
 """Main entry point into the Identity service."""
 
 from keystone.common import dependency
-from keystone.common import logging
 from keystone.common import manager
-from keystone.common import wsgi
 from keystone import config
 from keystone import exception
+from keystone.openstack.common import log as logging
 
 
 CONF = config.CONF
@@ -61,3 +60,6 @@ class Driver(object):
 
     def list_trusts_for_trustor(self, trustor):
         raise exception.NotImplemented()
+
+    def delete_trust(self, trust_id):
+        raise exception.NotImplemented()
